@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -117,6 +117,7 @@
 #include "hidkeys.h"
 #include "io_generic.h"
 #include "io_usb.h"
+#include "usb_hid.h"
 
 typedef enum {
   PARM_ROTATED_CELLS,
@@ -1678,12 +1679,12 @@ verifyPacket2u (
 static int
 setFeature2u (BrailleDisplay *brl, const unsigned char *request, size_t size) {
   logOutputPacket(request, size);
-  return gioSetHidFeature(brl->gioEndpoint, request[0], request, size) != -1;
+  return gioWriteHidFeature(brl->gioEndpoint, request, size) != -1;
 }
 
 static size_t
-getFeature2u (BrailleDisplay *brl, unsigned char feature, unsigned char *response, size_t size) {
-  ssize_t length = gioGetHidFeature(brl->gioEndpoint, feature, response, size);
+getFeature2u (BrailleDisplay *brl, HidReportIdentifier identifier, unsigned char *response, size_t size) {
+  ssize_t length = gioGetHidFeature(brl->gioEndpoint, identifier, response, size);
 
   if (length > 0) {
     logInputPacket(response, length);
