@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -40,7 +40,11 @@ typedef enum {
 } HW_MessageType;
 
 typedef enum {
-  HW_MODEL_BrailleNoteTouch = 0X10
+  HW_MODEL_HW_BRAILLE_NOTE_TOUCH = 0X10,
+  HW_MODEL_APH_CHAMELEON_20      = 0X11,
+  HW_MODEL_APH_MANTIS_Q40        = 0X12,
+  HW_MODEL_NLS_EREADER           = 0X13,
+  HW_MODEL_HW_BRAILLE_ONE        = 0X14,
 } HW_ModelIdentifier;
 
 typedef union {
@@ -134,42 +138,42 @@ typedef struct {
 } HW_PoweringOffReport;
 
 typedef enum {
-  HW_KEY_Reset     =  1,
+  HW_KEY_Reset         =  1,
 
-  HW_KEY_Dot1      =  2,
-  HW_KEY_Dot2      =  3,
-  HW_KEY_Dot3      =  4,
-  HW_KEY_Dot4      =  5,
-  HW_KEY_Dot5      =  6,
-  HW_KEY_Dot6      =  7,
-  HW_KEY_Dot7      =  8,
-  HW_KEY_Dot8      =  9,
-  HW_KEY_Space     = 10,
+  HW_KEY_Dot1          =  2,
+  HW_KEY_Dot2          =  3,
+  HW_KEY_Dot3          =  4,
+  HW_KEY_Dot4          =  5,
+  HW_KEY_Dot5          =  6,
+  HW_KEY_Dot6          =  7,
+  HW_KEY_Dot7          =  8,
+  HW_KEY_Dot8          =  9,
+  HW_KEY_Space         = 10,
 
-  HW_KEY_Command1  = 11,
-  HW_KEY_Command2  = 12,
-  HW_KEY_Command3  = 13,
-  HW_KEY_Command4  = 14,
-  HW_KEY_Command5  = 15,
-  HW_KEY_Command6  = 16,
+  HW_KEY_Command1      = 11,
+  HW_KEY_Command2      = 12,
+  HW_KEY_Command3      = 13,
+  HW_KEY_Command4      = 14,
+  HW_KEY_Command5      = 15,
+  HW_KEY_Command6      = 16,
 
-  HW_KEY_Thumb1    = 17,
-  HW_KEY_Thumb2    = 18,
-  HW_KEY_Thumb3    = 19,
-  HW_KEY_Thumb4    = 20,
+  HW_KEY_ThumbPrevious = 17,
+  HW_KEY_ThumbLeft     = 18,
+  HW_KEY_ThumbRight    = 19,
+  HW_KEY_ThumbNext     = 20,
 
-  HW_KEY_Up        = 21,
-  HW_KEY_Down      = 22,
-  HW_KEY_Left      = 23,
-  HW_KEY_Right     = 24,
-  HW_KEY_Action    = 25,
+  HW_KEY_Up            = 21,
+  HW_KEY_Down          = 22,
+  HW_KEY_Left          = 23,
+  HW_KEY_Right         = 24,
+  HW_KEY_Action        = 25,
 
-  HW_KEY_CAL_OK    = 30,
-  HW_KEY_CAL_FAIL  = 31,
-  HW_KEY_CAL_EMPTY = 32,
-  HW_KEY_CAL_RESET = 34,
+  HW_KEY_CAL_OK        = 30,
+  HW_KEY_CAL_FAIL      = 31,
+  HW_KEY_CAL_EMPTY     = 32,
+  HW_KEY_CAL_RESET     = 34,
 
-  HW_KEY_ROUTING   = 80
+  HW_KEY_ROUTING       = 80
 } HW_NavigationKey;
 
 typedef enum {
