@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -29,8 +29,10 @@
 #include "ascii.h"
 #include "cmd.h"
 #include "parse.h"
+#include "async_handle.h"
 #include "async_wait.h"
 #include "async_alarm.h"
+#include "timing.h"
 #include "ports.h"
 #include "message.h"
 
