@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -452,7 +452,7 @@ insertKey_AndroidScreen (ScreenKey key) {
     }
   }
 
-  logMessage(LOG_WARNING, "unsuported key: %04X", key);
+  logMessage(LOG_WARNING, "unsupported key: %04X", key);
   return 0;
 }
 
