@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -52,14 +52,14 @@ static unsigned char latin2cp437[0X80] =
    176, 151, 163, 150, 129, 178, 254, 152};
 
 static int
-spk_construct (volatile SpeechSynthesizer *spk, char **parameters)
+spk_construct (SpeechSynthesizer *spk, char **parameters)
 {
   return 1;
 }
 
 
 static void
-spk_say (volatile SpeechSynthesizer *spk, const unsigned char *buffer, size_t len, size_t count, const unsigned char *attributes)
+spk_say (SpeechSynthesizer *spk, const unsigned char *buffer, size_t len, size_t count, const unsigned char *attributes)
 {
   static unsigned char *pre_speech = (unsigned char *)PRE_SPEECH;
   static unsigned char *post_speech = (unsigned char *)POST_SPEECH;
@@ -98,7 +98,7 @@ spk_say (volatile SpeechSynthesizer *spk, const unsigned char *buffer, size_t le
 
 
 static void
-spk_mute (volatile SpeechSynthesizer *spk)
+spk_mute (SpeechSynthesizer *spk)
 {
   static unsigned char *mute_seq = (unsigned char *)MUTE_SEQ;
   unsigned char buffer[32];
@@ -109,6 +109,6 @@ spk_mute (volatile SpeechSynthesizer *spk)
 
 
 static void
-spk_destruct (volatile SpeechSynthesizer *spk)
+spk_destruct (SpeechSynthesizer *spk)
 {
 }
