@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -40,7 +40,7 @@ static const char *commandPath;	/* default full path for the say command */
 static FILE *commandStream = NULL;
 
 static int
-spk_construct (volatile SpeechSynthesizer *spk, char **parameters)
+spk_construct (SpeechSynthesizer *spk, char **parameters)
 {
   const char *command = parameters[PARM_COMMAND];
   commandPath = *command? command: SAY_CMD;
@@ -49,7 +49,7 @@ spk_construct (volatile SpeechSynthesizer *spk, char **parameters)
 }
 
 static void
-spk_say (volatile SpeechSynthesizer *spk, const unsigned char *buffer, size_t length, size_t count, const unsigned char *attributes) {
+spk_say (SpeechSynthesizer *spk, const unsigned char *buffer, size_t length, size_t count, const unsigned char *attributes) {
   if (!commandStream) {
     if (!(commandStream = popen(commandPath, "w"))) {
       logMessage(LOG_WARNING, "cannot start command: %s: %s",
@@ -76,7 +76,7 @@ spk_say (volatile SpeechSynthesizer *spk, const unsigned char *buffer, size_t le
 }
 
 static void
-spk_mute (volatile SpeechSynthesizer *spk)
+spk_mute (SpeechSynthesizer *spk)
 {
   if (commandStream)
     {
@@ -86,7 +86,7 @@ spk_mute (volatile SpeechSynthesizer *spk)
 }
 
 static void
-spk_destruct (volatile SpeechSynthesizer *spk)
+spk_destruct (SpeechSynthesizer *spk)
 {
    spk_mute(spk);
 }
