@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -391,19 +391,19 @@ loadSynthesisLibrary (void) {
 }
 
 static void
-spk_say (volatile SpeechSynthesizer *spk, const unsigned char *buffer, size_t length, size_t count, const unsigned char *attributes) {
+spk_say (SpeechSynthesizer *spk, const unsigned char *buffer, size_t length, size_t count, const unsigned char *attributes) {
   if (enqueueText(buffer, length))
     enqueueTag("<break time=\"none\"/>");
 }
 
 static void
-spk_mute (volatile SpeechSynthesizer *spk) {
+spk_mute (SpeechSynthesizer *spk) {
   stopSynthesisThread();
   if (pcm) cancelPcmOutput(pcm);
 }
 
 static void
-spk_setVolume (volatile SpeechSynthesizer *spk, unsigned char setting) {
+spk_setVolume (SpeechSynthesizer *spk, unsigned char setting) {
   char tag[0X40];
   unsigned int percentage = getIntegerSpeechVolume(setting, 100);
   snprintf(tag, sizeof(tag), "<volume level=\"%d\"/>",
@@ -412,7 +412,7 @@ spk_setVolume (volatile SpeechSynthesizer *spk, unsigned char setting) {
 }
 
 static void
-spk_setRate (volatile SpeechSynthesizer *spk, unsigned char setting) {
+spk_setRate (SpeechSynthesizer *spk, unsigned char setting) {
   char tag[0X40];
   snprintf(tag, sizeof(tag), "<rate absspeed=\"%d\"/>",
            getIntegerSpeechRate(setting, 10)-10);
@@ -420,7 +420,7 @@ spk_setRate (volatile SpeechSynthesizer *spk, unsigned char setting) {
 }
 
 static int
-spk_construct (volatile SpeechSynthesizer *spk, char **parameters) {
+spk_construct (SpeechSynthesizer *spk, char **parameters) {
   int code;
 
   spk->setVolume = spk_setVolume;
@@ -475,7 +475,7 @@ spk_construct (volatile SpeechSynthesizer *spk, char **parameters) {
 }
 
 static void
-spk_destruct (volatile SpeechSynthesizer *spk) {
+spk_destruct (SpeechSynthesizer *spk) {
   stopSynthesisThread();
   closeSoundDevice();
 
