@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -19,21 +19,13 @@
 #ifndef BRLTTY_INCLUDED_ASYNC_ALARM
 #define BRLTTY_INCLUDED_ASYNC_ALARM
 
-#include "async.h"
-#include "timing.h"
+#include "async_types_alarm.h"
+#include "async_types_handle.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-typedef struct {
-  const TimeValue *now;
-  void *data;
-} AsyncAlarmCallbackParameters;
-
-#define ASYNC_ALARM_CALLBACK(name) void name (const AsyncAlarmCallbackParameters *parameters)
-typedef ASYNC_ALARM_CALLBACK(AsyncAlarmCallback);
-
 extern int asyncNewAbsoluteAlarm (
   AsyncHandle *handle,
   const TimeValue *time,
