@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2018 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -19,16 +19,13 @@
 #ifndef BRLTTY_INCLUDED_ASYNC_TASK
 #define BRLTTY_INCLUDED_ASYNC_TASK
 
-#include "async.h"
-#include "async_event.h"
+#include "async_types_task.h"
+#include "async_types_event.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
-#define ASYNC_TASK_CALLBACK(name) void name (void *data)
-typedef ASYNC_TASK_CALLBACK(AsyncTaskCallback);
-
 extern int asyncAddTask (
   AsyncEvent *event,
   AsyncTaskCallback *callback, void *data
