@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -28,10 +28,14 @@ extern "C" {
 
 extern int isSpecialKey (ScreenKey key);
 extern void setScreenKeyModifiers (ScreenKey *key, ScreenKey which);
+extern void mapScreenKey (ScreenKey *key);
 
 typedef struct {
   const char * (*getTitle) (void);
 
+  void (*onForeground) (void);
+  void (*onBackground) (void);
+
   int (*poll) (void);
   int (*refresh) (void);
   void (*describe) (ScreenDescription *);
@@ -44,6 +48,9 @@ typedef struct {
   int (*unhighlightRegion) (void);
   int (*getPointer) (int *column, int *row);
 
+  int (*clearSelection) (void);
+  int (*setSelection) (int startColumn, int startRow, int endColumn, int endRow);
+
   int (*currentVirtualTerminal) (void);
   int (*selectVirtualTerminal) (int vt);
   int (*switchVirtualTerminal) (int vt);
