@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -19,7 +19,7 @@
 #ifndef BRLTTY_INCLUDED_ASYNC_INTERNAL
 #define BRLTTY_INCLUDED_ASYNC_INTERNAL
 
-#include "async.h"
+#include "async_handle.h"
 #include "queue.h"
 
 #ifdef __cplusplus
