@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -589,7 +589,11 @@ invokeMonitorCallback (OperationEntry *operation) {
       .data = operation->data
     };
 
-    if (callback(&parameters)) return 1;
+    if (callback(&parameters)) {
+      if (!operation->error) {
+        return 1;
+      }
+    }
   }
 
   return 0;
