@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -32,6 +32,8 @@
 #include "parameters.h"
 #include "io_bluetooth.h"
 #include "bluetooth_internal.h"
+#include "async_handle.h"
+#include "async_io.h"
 #include "io_misc.h"
 #include "timing.h"
 
@@ -641,9 +643,9 @@ void
 bthProcessDiscoveredDevices (
   DiscoveredBluetoothDeviceTester *testDevice, void *data
 ) {
+#ifdef HAVE_PKG_DBUS
   int found = 0;
 
-#ifdef HAVE_PKG_DBUS
   DBusError error;
   DBusConnection *bus;
  
