@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -25,6 +25,7 @@
 #include "report.h"
 #include "api_control.h"
 #include "queue.h"
+#include "async_handle.h"
 #include "async_alarm.h"
 #include "brl_base.h"
 #include "brl_utils.h"
@@ -409,6 +410,29 @@ writeBrailleMessage (
   return 0;
 }
 
+int
+getBrailleReportSize (BrailleDisplay *brl, unsigned char identifier, HidReportSize *size) {
+  return gioGetHidReportSize(brl->gioEndpoint, identifier, size);
+}
+
+int
+getBrailleReportSizes (BrailleDisplay *brl, const BrailleReportSizeEntry *table) {
+  const BrailleReportSizeEntry *entry = table;
+
+  while (entry->identifier) {
+    HidReportSize size;
+    if (!getBrailleReportSize(brl, entry->identifier, &size)) return 0;
+
+    if (entry->input) *entry->input = size.input;
+    if (entry->output) *entry->output = size.output;
+    if (entry->feature) *entry->feature = size.feature;
+
+    entry += 1;
+  }
+
+  return 1;
+}
+
 int
 probeBrailleDisplay (
   BrailleDisplay *brl, unsigned int retryLimit,
