@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -52,7 +52,6 @@ isTextOffset (int arg, int *first, int *last, int relaxed) {
   if (value < textStart) return 0;
   if ((value -= textStart) >= textCount) return 0;
 
-#ifdef ENABLE_CONTRACTED_BRAILLE
   if (isContracted) {
     int start = 0;
     int end = 0;
@@ -82,7 +81,6 @@ isTextOffset (int arg, int *first, int *last, int relaxed) {
     if (last) *last = end;
     return 1;
   }
-#endif /* ENABLE_CONTRACTED_BRAILLE */
 
   if ((ses->winx + value) >= scr.cols) {
     if (!relaxed) return 0;
@@ -140,6 +138,8 @@ STR_BEGIN_FORMATTER(formatCharacterDescription, int column, int row)
   }
 
   {
+    STR_PRINTF(" ");
+
     static const char *const colours[] = {
       /*      */ strtext("black"),
       /*    B */ strtext("blue"),
@@ -160,11 +160,16 @@ STR_BEGIN_FORMATTER(formatCharacterDescription, int column, int row)
     };
 
     unsigned char attributes = character.attributes;
-    STR_PRINTF(" %s", gettext(colours[attributes & SCR_MASK_FG]));
-    STR_PRINTF(" on %s", gettext(colours[(attributes & SCR_MASK_BG) >> 4]));
+    const char *foreground = gettext(colours[attributes & SCR_MASK_FG]);
+    const char *background = gettext(colours[(attributes & SCR_MASK_BG) >> 4]);
+
+    // xgettext: This phrase describes the colour of a character on the screen.
+    // xgettext: %1$s is the (already translated) foreground colour.
+    // xgettext: %2$s is the (already translated) background colour.
+    STR_PRINTF(gettext("%1$s on %2$s"), foreground, background);
   }
 
   if (character.attributes & SCR_ATTR_BLINK) {
-    STR_PRINTF(" %s", gettext("blink"));
+    STR_PRINTF(" %s", gettext("blinking"));
   }
 STR_END_FORMATTER
