@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -345,6 +345,11 @@ parseDataString (DataFile *file, DataString *string, const wchar_t *characters,
             ok = 1;
             break;
 
+          case WC_C('R'):
+            character = UNICODE_REPLACEMENT_CHARACTER;
+            ok = 1;
+            break;
+
           case WC_C('s'):
             character = WC_C(' ');
             ok = 1;
