@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -44,6 +44,7 @@
 #include "log.h"
 #include "strfmt.h"
 #include "file.h"
+#include "lock.h"
 #include "parse.h"
 #include "async_wait.h"
 #include "utf8.h"
@@ -335,6 +336,22 @@ testDirectoryPath (const char *path) {
   return 0;
 }
 
+static LockDescriptor *
+getUmaskLock (void) {
+  static LockDescriptor *lock = NULL;
+  return getLockDescriptor(&lock, "umask");
+}
+
+void
+lockUmask (void) {
+  obtainExclusiveLock(getUmaskLock());
+}
+
+void
+unlockUmask (void) {
+  releaseLock(getUmaskLock());
+}
+
 int
 createDirectory (const char *path, int worldWritable) {
 #if defined(GRUB_RUNTIME)
@@ -344,7 +361,11 @@ createDirectory (const char *path, int worldWritable) {
 #ifdef __MINGW32__
   if (mkdir(path) != -1) return 1;
 #else /* __MINGW32__ */
-  if (mkdir(path, (S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH)) != -1) {
+  lockUmask();
+  int created = mkdir(path, (S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH)) != -1;
+  unlockUmask();
+
+  if (created) {
     if (!worldWritable) return 1;
     mode_t mode = 0;
 
@@ -364,7 +385,13 @@ createDirectory (const char *path, int worldWritable) {
     mode |= S_ISVTX;
     #endif /* S_ISVTX */
 
-    if (chmod(path, mode) != -1) return 1;
+    {
+      lockUmask();
+      int changed = chmod(path, mode) != -1;
+      unlockUmask();
+      if (changed) return 1;
+    }
+
     logMessage(LOG_WARNING,
       "%s: %s: %s",
       gettext("cannot make world writable"),
@@ -1030,6 +1057,28 @@ STR_BEGIN_FORMATTER(formatInputError, const char *file, const int *line, const c
 STR_END_FORMATTER
 
 #ifdef __MINGW32__
+int
+getConsoleSize (size_t *width, size_t *height) {
+  HANDLE handle = GetStdHandle(STD_OUTPUT_HANDLE);
+
+  if (handle) {
+    if (handle != INVALID_HANDLE_VALUE) {
+      if (GetFileType(handle) == FILE_TYPE_CHAR) {
+        CONSOLE_SCREEN_BUFFER_INFO info;
+
+        if (GetConsoleScreenBufferInfo(handle, &info)) {
+          COORD size = info.dwSize;
+          if (width) *width = size.X;
+          if (height) *height = size.Y;
+          return 1;
+        }
+      }
+    }
+  }
+
+  return 0;
+}
+
 const char *
 getConsoleEncoding (void) {
   static char encoding[0X10];
@@ -1097,6 +1146,18 @@ createAnonymousPipe (FileDescriptor *pipeInput, FileDescriptor *pipeOutput) {
 }
 
 #else /* unix file/socket descriptor operations */
+#include <sys/ioctl.h>
+
+int
+getConsoleSize (size_t *width, size_t *height) {
+  struct winsize size;
+  if (ioctl(STDOUT_FILENO, TIOCGWINSZ, &size) == -1) return 0;
+
+  if (width) *width = size.ws_col;
+  if (height) *height = size.ws_row;
+  return 1;
+}
+
 const char *
 getConsoleEncoding (void) {
   static const char *encoding = NULL;
@@ -1154,7 +1215,8 @@ createAnonymousPipe (FileDescriptor *pipeInput, FileDescriptor *pipeOutput) {
 
 void
 writeWithConsoleEncoding (FILE *stream, const char *bytes, size_t count) {
-  const char *consoleEncoding = getConsoleEncoding();
+  static const char *consoleEncoding = NULL;
+  if (!consoleEncoding) consoleEncoding = getConsoleEncoding();
 
   if (!consoleEncoding || isCharsetUTF8(consoleEncoding)) {
     consoleEncoding = "";
@@ -1162,17 +1224,20 @@ writeWithConsoleEncoding (FILE *stream, const char *bytes, size_t count) {
 
 #ifdef HAVE_ICONV_H
   if (*consoleEncoding) {
-    static const char internalEncoding[] = "UTF-8";
     static iconv_t iconvHandle = (iconv_t)-1;
 
     if (iconvHandle == (iconv_t)-1) {
-      if ((iconvHandle = iconv_open(consoleEncoding, internalEncoding)) == (iconv_t)-1) {
+      static const char internalEncoding[] = "UTF-8";
+      const char *externalEncoding = consoleEncoding;
+
+      if ((iconvHandle = iconv_open(externalEncoding, internalEncoding)) == (iconv_t)-1) {
+        consoleEncoding = "";
+
         logMessage(LOG_WARNING,
           "iconv open error: %s -> %s: %s",
-          internalEncoding, consoleEncoding, strerror(errno)
+          internalEncoding, externalEncoding, strerror(errno)
         );
 
-        consoleEncoding = "";
         goto ENCODING_NOT_SUPPORTED;
       }
     }
