@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -26,6 +26,7 @@
 #include "io_misc.h"
 #include "log.h"
 #include "file.h"
+#include "async_handle.h"
 #include "async_wait.h"
 #include "async_io.h"
 
@@ -152,7 +153,6 @@ readData (
 
       if (timeout) {
         if (awaitInput(ioh, timeout)) continue;
-        logMessage(LOG_WARNING, "input byte missing at offset %u", offset);
       } else
 
 #ifdef __MSDOS__
