@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -750,11 +750,9 @@ listKeyTableTitle (ListGenerationData *lgd) {
 
 static int
 listKeyTableNotes (ListGenerationData *lgd) {
-  unsigned int noteIndex;
-
   if (!beginList(lgd, "Notes")) return 0;
 
-  for (noteIndex=0; noteIndex<lgd->keyTable->notes.count; noteIndex+=1) {
+  for (unsigned int noteIndex=0; noteIndex<lgd->keyTable->notes.count; noteIndex+=1) {
     const wchar_t *line = lgd->keyTable->notes.table[noteIndex];
     unsigned int level;
     int prefixed;
