@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -23,7 +23,7 @@
 
 #include "lock.h"
 #include "log.h"
-#include "get_pthreads.h"
+#include "get_thread.h"
  
 #undef CAN_LOCK
 #if defined(PTHREAD_RWLOCK_INITIALIZER)
