@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -609,7 +609,9 @@ processCommandLine (
   *argumentCount -= optind;
 
   if (optHelp) {
-    showUsageSummary(info, stdout, 79, argumentsSummary, optHelpAll);
+    size_t width = UINT16_MAX;
+    getConsoleSize(&width, NULL);
+    showUsageSummary(info, stdout, width, argumentsSummary, optHelpAll);
     info->exitImmediately = 1;
   }
 
