@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -69,8 +69,10 @@ changeStringSetting (char **setting, const char *value) {
 
 int
 extendStringSetting (char **setting, const char *value, int prepend) {
-  if (value && *value) {
-    if (*setting) {
+  if (!value) value = "";
+
+  if (*setting && **setting) {
+    if (*value) {
       size_t newSize = strlen(*setting) + 1 + strlen(value) + 1;
       char newSetting[newSize];
 
@@ -81,9 +83,9 @@ extendStringSetting (char **setting, const char *value, int prepend) {
       }
 
       if (!changeStringSetting(setting, newSetting)) return 0;
-    } else if (!changeStringSetting(setting, value)) {
-      return 0;
     }
+  } else if (!changeStringSetting(setting, value)) {
+    return 0;
   }
 
   return 1;
@@ -421,19 +423,18 @@ parseParameters (
     while (1) {
       const char *parameterEnd = strchr(parameter, PARAMETER_SEPARATOR_CHARACTER);
       int done = !parameterEnd;
-      int parameterLength;
 
       if (done) parameterEnd = parameter + strlen(parameter);
-      parameterLength = parameterEnd - parameter;
+      int parameterLength = parameterEnd - parameter;
 
       if (parameterLength > 0) {
         const char *value = memchr(parameter, PARAMETER_ASSIGNMENT_CHARACTER, parameterLength);
 
         if (!value) {
-          logMessage(LOG_ERR, "%s: %.*s",
+          logMessage(LOG_WARNING, "%s: %.*s",
                      gettext("missing parameter value"),
                      parameterLength, parameter);
-          return 0;
+          goto NEXT_PARAMETER;
         }
 
         {
@@ -454,10 +455,10 @@ parseParameters (
               isEligible = 0;
 
               if (!qualifierLength) {
-                logMessage(LOG_ERR, "%s: %.*s",
+                logMessage(LOG_WARNING, "%s: %.*s",
                            gettext("missing parameter qualifier"),
                            parameterLength, parameter);
-                return 0;
+                goto NEXT_PARAMETER;
               }
 
               if ((qualifierLength == strlen(qualifier)) &&
@@ -468,10 +469,10 @@ parseParameters (
           }
 
           if (!nameLength) {
-            logMessage(LOG_ERR, "%s: %.*s",
+            logMessage(LOG_WARNING, "%s: %.*s",
                        gettext("missing parameter name"),
                        parameterLength, parameter);
-            return 0;
+            goto NEXT_PARAMETER;
           }
 
           if (isEligible) {
@@ -491,21 +492,21 @@ parseParameters (
 
                 free(values[index]);
                 values[index] = newValue;
-                goto parameterDone;
+                goto NEXT_PARAMETER;
               }
 
               index += 1;
             }
 
-            logMessage(LOG_ERR, "%s: %.*s",
+            logMessage(LOG_WARNING, "%s: %.*s",
                        gettext("unsupported parameter"),
                        parameterLength, parameter);
-            return 0;
+            goto NEXT_PARAMETER;
           }
         }
       }
 
-    parameterDone:
+    NEXT_PARAMETER:
       if (done) break;
       parameter = parameterEnd + 1;
     }
