@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -22,6 +22,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <errno.h>
+#include <locale.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <limits.h>
@@ -87,6 +88,7 @@ beginProgram (int argumentCount, char **argumentVector) {
   atexit(endProgram);
 #endif /* at exit */
 
+  setlocale(LC_ALL, "");
   initializeSystemObject();
   ensureAllMessagesProperties();
 
@@ -190,16 +192,18 @@ createPidFile (const char *path, ProcessIdentifier pid) {
 
     typedef enum {PFS_ready, PFS_stale, PFS_clash, PFS_error} PidFileState;
     PidFileState state = PFS_error;
-    int file = open(path,
-                    O_RDWR | O_CREAT,
-                    S_IRUSR | S_IWUSR
+
+    lockUmask();
+    int file = open(
+      path, O_RDWR | O_CREAT, S_IRUSR | S_IWUSR
 #ifdef S_IRGRP
-                    | S_IRGRP
+                            | S_IRGRP
 #endif /* S_IRGRP */
 #ifdef S_IROTH
-                    | S_IROTH
+                            | S_IROTH
 #endif /* S_IROTH */
-                    );
+    );
+    unlockUmask();
 
     if (file != -1) {
       int locked = acquireFileLock(file, 1);
