@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -46,11 +46,6 @@ getScreenParameters (const ScreenDriver *driver) {
   return driver->parameters;
 }
 
-const DriverDefinition *
-getScreenDriverDefinition (const ScreenDriver *driver) {
-  return &driver->definition;
-}
-
 static void
 initializeScreen (void) {
   screen->initialize(&mainScreen);
