@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -90,6 +90,17 @@ setScreenKeyModifiers (ScreenKey *key, ScreenKey which) {
   }
 }
 
+void
+mapScreenKey (ScreenKey *key) {
+  switch (*key & SCR_KEY_CHAR_MASK) {
+    case '\n':
+    case '\r':   *key = SCR_KEY_ENTER;     break;
+    case '\t':   *key = SCR_KEY_TAB;       break;
+    case '\b':   *key = SCR_KEY_BACKSPACE; break;
+    case '\033': *key = SCR_KEY_ESCAPE;    break;
+  }
+}
+
 static const char text_BaseScreen[] = " ";
 
 static int
