@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -22,6 +22,8 @@
 #include <errno.h>
 
 #include "log.h"
+#include "io_log.h"
+#include "strfmt.h"
 #include "parameters.h"
 #include "parse.h"
 #include "device.h"
@@ -44,6 +46,11 @@
 
 #include "serial_internal.h"
 
+const char *
+serialGetDevicePath (SerialDevice *serial) {
+  return serial->devicePath;
+}
+
 const SerialBaudEntry *
 serialGetBaudEntry (unsigned int baud) {
   const SerialBaudEntry *entry = serialBaudTable;
@@ -104,7 +111,7 @@ serialSetBaud (SerialDevice *serial, unsigned int baud) {
   if (entry) {
     logMessage(LOG_CATEGORY(SERIAL_IO), "set baud: %u", baud);
     if (serialPutSpeed(&serial->pendingAttributes, entry->speed)) return 1;
-    logMessage(LOG_WARNING, "unsupported serial baud: %u", baud);
+    logUnsupportedBaud(baud);
   }
 
   return 0;
@@ -139,7 +146,7 @@ serialSetDataBits (SerialDevice *serial, unsigned int bits) {
   logMessage(LOG_CATEGORY(SERIAL_IO), "set data bits: %u", bits);
   if (serialPutDataBits(&serial->pendingAttributes, bits)) return 1;
 
-  logMessage(LOG_WARNING, "unsupported serial data bit count: %u", bits);
+  logUnsupportedDataBits(bits);
   return 0;
 }
 
@@ -148,7 +155,7 @@ serialSetStopBits (SerialDevice *serial, SerialStopBits bits) {
   logMessage(LOG_CATEGORY(SERIAL_IO), "set stop bits: %u", bits);
   if (serialPutStopBits(&serial->pendingAttributes, bits)) return 1;
 
-  logMessage(LOG_WARNING, "unsupported serial stop bit count: %u", bits);
+  logUnsupportedStopBits(bits);
   return 0;
 }
 
@@ -157,7 +164,7 @@ serialSetParity (SerialDevice *serial, SerialParity parity) {
   logMessage(LOG_CATEGORY(SERIAL_IO), "set parity: %u", parity);
   if (serialPutParity(&serial->pendingAttributes, parity)) return 1;
 
-  logMessage(LOG_WARNING, "unsupported serial parity: %u", parity);
+  logUnsupportedParity(parity);
   return 0;
 }
 
@@ -234,7 +241,7 @@ serialSetFlowControl (SerialDevice *serial, SerialFlowControl flow) {
 #endif /* HAVE_POSIX_THREADS */
 
   if (!flow) return 1;
-  logMessage(LOG_WARNING, "unsupported serial flow control: 0X%02X", flow);
+  logUnsupportedFlowControl(flow);
   return 0;
 }
 
@@ -669,28 +676,28 @@ serialConfigureFlowControl (SerialDevice *serial, const char *string) {
 }
 
 typedef enum {
-  SERIAL_DEV_NAME,
-  SERIAL_DEV_BAUD,
-  SERIAL_DEV_DATA_BITS,
-  SERIAL_DEV_STOP_BITS,
-  SERIAL_DEV_PARITY,
-  SERIAL_DEV_FLOW_CONTROL
+  SERIAL_PARM_NAME,
+  SERIAL_PARM_BAUD,
+  SERIAL_PARM_DATA_BITS,
+  SERIAL_PARM_STOP_BITS,
+  SERIAL_PARM_DATA_PARITY,
+  SERIAL_PARM_FLOW_CONTROL
 } SerialDeviceParameter;
 
+static const char *const serialDeviceParameterNames[] = {
+  "name",
+  "baud",
+  "dataBits",
+  "stopBits",
+  "parity",
+  "flowControl",
+  NULL
+};
+
 static char **
 serialGetDeviceParameters (const char *identifier) {
-  static const char *const names[] = {
-    "name",
-    "baud",
-    "dataBits",
-    "stopBits",
-    "parity",
-    "flowControl",
-    NULL
-  };
-
   if (!identifier) identifier = "";
-  return getDeviceParameters(names, identifier);
+  return getDeviceParameters(serialDeviceParameterNames, identifier);
 }
 
 SerialDevice *
@@ -701,33 +708,26 @@ serialOpenDevice (const char *identifier) {
     SerialDevice *serial;
 
     if ((serial = malloc(sizeof(*serial)))) {
-      char *path;
+      memset(serial, 0, sizeof(*serial));
 
       {
-        const char *name = parameters[SERIAL_DEV_NAME];
-
+        const char *name = parameters[SERIAL_PARM_NAME];
         if (!*name) name = SERIAL_FIRST_DEVICE;
-        path = getDevicePath(name);
+        serial->devicePath = getDevicePath(name);
       }
 
-      if (path) {
-        int connected;
-
+      if (serial->devicePath) {
         serial->fileDescriptor = -1;
         serial->stream = NULL;
 
-        connected = serialConnectDevice(serial, path);
-        free(path);
-        path = NULL;
-
-        if (connected) {
+        if (serialConnectDevice(serial, serial->devicePath)) {
           int ok = 1;
 
-          if (!serialConfigureBaud(serial, parameters[SERIAL_DEV_BAUD])) ok = 0;
-          if (!serialConfigureDataBits(serial, parameters[SERIAL_DEV_DATA_BITS])) ok = 0;
-          if (!serialConfigureStopBits(serial, parameters[SERIAL_DEV_STOP_BITS])) ok = 0;
-          if (!serialConfigureParity(serial, parameters[SERIAL_DEV_PARITY])) ok = 0;
-          if (!serialConfigureFlowControl(serial, parameters[SERIAL_DEV_FLOW_CONTROL])) ok = 0;
+          if (!serialConfigureBaud(serial, parameters[SERIAL_PARM_BAUD])) ok = 0;
+          if (!serialConfigureDataBits(serial, parameters[SERIAL_PARM_DATA_BITS])) ok = 0;
+          if (!serialConfigureStopBits(serial, parameters[SERIAL_PARM_STOP_BITS])) ok = 0;
+          if (!serialConfigureParity(serial, parameters[SERIAL_PARM_DATA_PARITY])) ok = 0;
+          if (!serialConfigureFlowControl(serial, parameters[SERIAL_PARM_FLOW_CONTROL])) ok = 0;
 
           deallocateStrings(parameters);
           if (ok) return serial;
@@ -735,6 +735,8 @@ serialOpenDevice (const char *identifier) {
           serialCloseDevice(serial);
           return NULL;
         }
+
+        free(serial->devicePath);
       }
 
       free(serial);
@@ -764,9 +766,27 @@ serialCloseDevice (SerialDevice *serial) {
     serialDisconnectDevice(serial);
   }
 
+  free(serial->devicePath);
   free(serial);
 }
 
+const char *
+serialMakeDeviceIdentifier (SerialDevice *serial, char *buffer, size_t size) {
+  STR_BEGIN(buffer, size);
+
+  STR_PRINTF(
+    "%s%c%s%c%s",
+    SERIAL_DEVICE_QUALIFIER,
+    PARAMETER_QUALIFIER_CHARACTER,
+    serialDeviceParameterNames[SERIAL_PARM_NAME],
+    PARAMETER_ASSIGNMENT_CHARACTER,
+    serialGetDevicePath(serial)
+  );
+
+  STR_END;
+  return buffer;
+}
+
 int
 serialRestartDevice (SerialDevice *serial, unsigned int baud) {
   SerialLines highLines = 0;
@@ -871,7 +891,7 @@ isSerialDeviceIdentifier (const char **identifier) {
   if (isDosDevice(*identifier, "COM")) return 1;
 #endif /* ALLOW_DOS_DEVICE_NAMES */
 
-  if (hasQualifier(identifier, "serial")) return 1;
+  if (hasQualifier(identifier, SERIAL_DEVICE_QUALIFIER)) return 1;
   if (hasNoQualifier(*identifier)) return 1;
   return 0;
 }
