@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -26,7 +26,7 @@
 #include <sys/modem.h>
 #endif /* HAVE_SYS_MODEM_H */
 
-#include "async.h"
+#include "async_handle.h"
 
 #ifdef __cplusplus
 extern "C" {
