@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -243,7 +243,7 @@ convertCharacterToDots (TextTable *table, wchar_t character) {
 wchar_t
 convertDotsToCharacter (TextTable *table, unsigned char dots) {
   const TextTableHeader *header = table->header.fields;
-  if (BITMASK_TEST(header->dotsCharacterDefined, dots)) return header->dotsToCharacter[dots];
+  if (BITMASK_TEST(header->inputCharacterDefined, dots)) return header->inputCharacters[dots];
   return UNICODE_REPLACEMENT_CHARACTER;
 }
 
