@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -37,7 +37,6 @@
 static int
 isUcharCompatible (wchar_t character) {
   UChar uc = character;
-
   return uc == character;
 }
 
@@ -167,6 +166,15 @@ isBrailleCharacter (wchar_t character) {
   return (character & ~UNICODE_CELL_MASK) == UNICODE_BRAILLE_ROW;
 }
 
+int
+isIdeographicCharacter (wchar_t character) {
+#ifdef HAVE_ICU
+  if (u_hasBinaryProperty(character, UCHAR_IDEOGRAPHIC)) return 1;
+#endif /* HAVE_ICU */
+
+  return 0;
+}
+
 int
 isEmojiSequence (const wchar_t *characters, size_t count) {
 #ifdef HAVE_ICU
@@ -175,7 +183,11 @@ isEmojiSequence (const wchar_t *characters, size_t count) {
 
   while (character < end) {
     #if U_ICU_VERSION_MAJOR_NUM >= 57
-    if (u_hasBinaryProperty(*character, UCHAR_EMOJI)) return 1;
+    if (u_hasBinaryProperty(*character, UCHAR_EMOJI)) {
+      if (u_hasBinaryProperty(*character, UCHAR_EMOJI_PRESENTATION)) {
+        return 1;
+      }
+    }
     #endif /* U_ICU_VERSION_MAJOR_NUM >= 57 */
 
     character += 1;
@@ -195,7 +207,7 @@ getReplacementCharacter (void) {
 }
 
 int
-normalizeCharacters (
+composeCharacters (
   size_t *length, const wchar_t *characters,
   wchar_t *buffer, unsigned int *map
 ) {
@@ -271,41 +283,66 @@ normalizeCharacters (
 #endif /* HAVE_ICU */
 }
 
-wchar_t
-getBaseCharacter (wchar_t character) {
+size_t
+decomposeCharacter (
+  wchar_t character, wchar_t *buffer, size_t length
+) {
 #ifdef HAVE_ICU
   if (isUcharCompatible(character)) {
-    UChar source[] = {character};
-    const unsigned int resultLength = 0X10;
-    UChar resultBuffer[resultLength];
-    UErrorCode error = U_ZERO_ERROR;
+    UChar source[1] = {character};
+    UChar target[length];
+    int32_t count;
+
+    {
+      UErrorCode error = U_ZERO_ERROR;
 
 #ifdef HAVE_UNICODE_UNORM2_H
-    static const UNormalizer2 *normalizer = NULL;
+      static const UNormalizer2 *normalizer = NULL;
+
+      if (!normalizer) {
+        normalizer = unorm2_getNFDInstance(&error);
+        if (!U_SUCCESS(error)) return 0;
+      }
+
+      count = unorm2_normalize(normalizer,
+                               source, ARRAY_COUNT(source),
+                               target, ARRAY_COUNT(target),
+                               &error);
+#else /* unorm */
+      count = unorm_normalize(source, ARRAY_COUNT(source),
+                              UNORM_NFD, 0,
+                              target, ARRAY_COUNT(target),
+                              &error);
+#endif /* unorm */
 
-    if (!normalizer) {
-      normalizer = unorm2_getNFDInstance(&error);
       if (!U_SUCCESS(error)) return 0;
     }
 
-    unorm2_normalize(normalizer,
-                     source, ARRAY_COUNT(source),
-                     resultBuffer, resultLength,
-                     &error);
-#else /* unorm */
-    unorm_normalize(source, ARRAY_COUNT(source),
-                    UNORM_NFD, 0,
-                    resultBuffer, resultLength,
-                    &error);
-#endif /* unorm */
+    {
+      const UChar *trg = target;
+      const UChar *end = target + count;
+      wchar_t *out = buffer;
 
-    if (U_SUCCESS(error)) return resultBuffer[0];
+      while (trg < end) {
+        *out++ = *trg++;
+      }
+    }
+
+    return count;
   }
 #endif /* HAVE_ICU */
 
   return 0;
 }
 
+wchar_t
+getBaseCharacter (wchar_t character) {
+  wchar_t decomposed[0X10];
+  size_t count = decomposeCharacter(character, decomposed, sizeof(decomposed));
+  if (count) return decomposed[0];
+  return 0;
+}
+
 wchar_t
 getTransliteratedCharacter (wchar_t character) {
 #ifdef HAVE_ICONV_H
