@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -27,6 +27,7 @@
 #include "report.h"
 #include "strfmt.h"
 #include "update.h"
+#include "async_handle.h"
 #include "async_alarm.h"
 #include "timing.h"
 #include "unicode.h"
@@ -181,7 +182,7 @@ setSpeechCursorDots (unsigned char dots) {
   return setCursorDots(&prefs.speechCursorStyle, dots);
 }
 
-static unsigned char
+unsigned char
 mapCursorDots (unsigned char dots) {
   if (!hasEightDotCells(&brl)) {
     brlRemapDot(&dots, BRL_DOT_7, BRL_DOT_3);
