@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -25,11 +25,11 @@
 }
 
 const UsbDeviceEntry usbDeviceTable[] = {
-// BEGIN_USB_DEVICES
+// BEGIN_USB_BRAILLE_DEVICES
 
 // Device: 0403:6001
 // Generic Identifier
-// Vendor: Future Technology Devices International, Ltd
+// Vendor: Future Technology Devices International, Ltd.
 // Product: FT232 USB-Serial (UART) IC
 // Albatross [all models]
 // Cebra [all models]
@@ -94,13 +94,17 @@ USB_DEVICE_ENTRY(0X0452, 0X0100, "mt"),
 USB_DEVICE_ENTRY(0X045E, 0X930A, "hm"),
 
 // Device: 045E:930B
-// HIMS [Braille Edge]
+// HIMS [Braille Edge and QBrailleXL]
 USB_DEVICE_ENTRY(0X045E, 0X930B, "hm"),
 
 // Device: 0483:A1D3
-// Baum [Orbit 20 (20 cells)]
+// Baum [Orbit Reader 20 (20 cells)]
 USB_DEVICE_ENTRY(0X0483, 0XA1D3, "bm"),
 
+// Device: 0483:A366
+// Baum [Orbit Reader 40 (40 cells)]
+USB_DEVICE_ENTRY(0X0483, 0XA366, "bm"),
+
 // Device: 06B0:0001
 // Alva [Satellite (5nn)]
 USB_DEVICE_ENTRY(0X06B0, 0X0001, "al"),
@@ -314,6 +318,9 @@ USB_DEVICE_ENTRY(0X1209, 0XABC0, "ic"),
 USB_DEVICE_ENTRY(0X16C0, 0X05E1, "cn"),
 
 // Device: 1A86:7523
+// Generic Identifier
+// Vendor: Jiangsu QinHeng, Ltd.
+// Product: CH341 USB Bridge Controller
 // Baum [NLS eReader Zoomax (20 cells)]
 USB_DEVICE_ENTRY(0X1A86, 0X7523, "bm"),
 
@@ -520,7 +527,7 @@ USB_DEVICE_ENTRY(0XC251, 0X1131, "eu"),
 // EuroBraille [reserved]
 USB_DEVICE_ENTRY(0XC251, 0X1132, "eu"),
 
-// END_USB_DEVICES
+// END_USB_BRAILLE_DEVICES
 };
 
 const uint16_t usbDeviceCount = ARRAY_COUNT(usbDeviceTable);
