@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2022 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -37,12 +37,14 @@
 #define USBDEVFS_CONNECT _IO('U', 23)
 #endif /* USBDEVFS_CONNECT */
 
-#include "parameters.h"
 #include "log.h"
+#include "parameters.h"
+#include "bitfield.h"
 #include "strfmt.h"
 #include "file.h"
 #include "parse.h"
 #include "timing.h"
+#include "async_handle.h"
 #include "async_wait.h"
 #include "async_alarm.h"
 #include "async_io.h"
