@@ -2,7 +2,7 @@
 # BRLTTY - A background process providing access to the console screen (when in
 #          text mode) for a blind person using a refreshable braille display.
 #
-# Copyright (C) 1995-2021 by The BRLTTY Developers.
+# Copyright (C) 1995-2022 by The BRLTTY Developers.
 #
 # BRLTTY comes with ABSOLUTELY NO WARRANTY.
 #
@@ -16,9 +16,118 @@
 # This software is maintained by Dave Mielke <dave@mielke.cc>.
 ###############################################################################
 
+testMode=false
+
 readonly initialDirectory="$(pwd)"
 readonly programName="$(basename "${0}")"
 
+programMessage() {
+   local message="${1}"
+
+   [ -z "${message}" ] || echo >&2 "${programName}: ${message}"
+}
+
+setVariable() {
+   eval "${1}"'="${2}"'
+}
+
+getVariable() {
+   if [ -n "${2}" ]
+   then
+      eval "${2}"'="${'"${1}"'}"'
+   else
+      eval 'echo "${'"${1}"'}"'
+   fi
+}
+
+defineEnumeration() {
+   local prefix="${1}"
+   shift 1
+
+   local name
+   local value=1
+
+   for name
+   do
+      local variable="${prefix}${name}"
+      readonly "${variable}"="${value}"
+      value=$((value + 1))
+   done
+}
+
+defineEnumeration programLogLevel_ error warning notice task note detail
+programLogLevel=$((${programLogLevel_task}))
+
+logMessage() {
+   local level="${1}"
+   local message="${2}"
+
+   local variable="programLogLevel_${level}"
+   local value=$((${variable}))
+
+   [ "${value}" -gt 0 ] || programMessage "unknown log level: ${level}"
+   [ "${value}" -gt "${programLogLevel}" ] || programMessage "${message}"
+}
+
+logError() {
+   logMessage error "${@}"
+}
+
+logWarning() {
+   logMessage warning "${@}"
+}
+
+logNotice() {
+   logMessage notice "${@}"
+}
+
+logTask() {
+   logMessage task "${@}"
+}
+
+logNote() {
+   logMessage note "${@}"
+}
+
+logDetail() {
+   logMessage detail "${@}"
+}
+
+programTerminationCommandCount=0
+
+runProgramTerminationCommands() {
+   set +e
+
+   while [ "${programTerminationCommandCount}" -gt 0 ]
+   do
+      set -- $(getVariable "programTerminationCommand${programTerminationCommandCount}")
+      let "programTerminationCommandCount -= 1"
+
+      local process="${1}"
+      local directory="${2}"
+      shift 2
+
+      [ "${process}" = "${$}" ] && {
+         cd "${directory}"
+         "${@}"
+      }
+   done
+}
+
+pushProgramTerminationCommand() {
+   [ "${programTerminationCommandCount}" -gt 0 ] || trap runProgramTerminationCommands exit
+   setVariable "programTerminationCommand$((programTerminationCommandCount += 1))" "${$} $(pwd) ${*}"
+}
+
+needTemporaryDirectory() {
+   [ -n "${temporaryDirectory}" ] || {
+      umask 022
+      [ -n "${TMPDIR}" -a -d "${TMPDIR}" -a -r "${TMPDIR}" -a -w "${TMPDIR}" -a -x "${TMPDIR}" ] || export TMPDIR="/tmp"
+      temporaryDirectory="$(mktemp -d "${TMPDIR}/${programName}.$(date +"%Y%m%d-%H%M%S").XXXXXX")" && cd "${temporaryDirectory}" || exit "${?}"
+      pushProgramTerminationCommand rm -f -r -- "${temporaryDirectory}"
+   }
+}
+
 resolveDirectory() {
    local path="${1}"
    local variable="${2}"
@@ -32,6 +141,9 @@ resolveDirectory() {
    fi
 }
 
+programDirectory="$(dirname "${0}")"
+readonly programDirectory="$(resolveDirectory "${programDirectory}")"
+
 toRelativePath() {
    local toPath="${1}"
    local variable="${2}"
@@ -79,37 +191,6 @@ toRelativePath() {
    fi
 }
 
-programDirectory="$(dirname "${0}")"
-readonly programDirectory="$(resolveDirectory "${programDirectory}")"
-
-setVariable() {
-   eval "${1}"'="${2}"'
-}
-
-getVariable() {
-   if [ -n "${2}" ]
-   then
-      eval "${2}"'="${'"${1}"'}"'
-   else
-      eval 'echo "${'"${1}"'}"'
-   fi
-}
-
-defineEnumeration() {
-   local prefix="${1}"
-   shift 1
-
-   local name
-   local value=1
-
-   for name
-   do
-      local variable="${prefix}${name}"
-      readonly "${variable}"="${value}"
-      value=$((value + 1))
-   done
-}
-
 parseParameterString() {
    local valuesArray="${1}"
    local parameters="${2}"
@@ -200,47 +281,119 @@ stringWrapped() {
    echo "${result}"
 }
 
-programMessage() {
-   local message="${1}"
-
-   [ -z "${message}" ] || echo >&2 "${programName}: ${message}"
-}
-
-defineEnumeration programLogLevel_ error warning notice task step detail
-programLogLevel=$((${programLogLevel_task}))
-
-logMessage() {
-   local level="${1}"
-   local message="${2}"
-
-   local variable="programLogLevel_${level}"
-   local value=$((${variable}))
-
-   [ "${value}" -gt 0 ] || programMessage "unknown log level: ${level}"
-   [ "${value}" -gt "${programLogLevel}" ] || programMessage "${message}"
-}
-
 syntaxError() {
    local message="${1}"
 
-   logMessage error "${message}"
+   logError "${message}"
    exit 2
 }
 
 semanticError() {
    local message="${1}"
 
-   logMessage error "${message}"
+   logError "${message}"
    exit 3
 }
 
 internalError() {
    local message="${1}"
 
-   logMessage error "${message}"
+   logError "${message}"
    exit 4
 }
 
+findHostCommand() {
+   local pathVariable="${1}"
+   local command="${2}"
+
+   local path="$(which "${command}")"
+   [ -n "${path}" ] || return 1
+
+   setVariable "${pathVariable}" "${path}"
+   return 0
+}
+
+verifyHostCommand() {
+   local pathVariable="${1}"
+   local command="${2}"
+
+   findHostCommand "${pathVariable}" "${command}" || {
+      semanticError "host command not found: ${command}"
+   }
+}
+
+executeHostCommand() {
+   logDetail "executing host command: ${*}"
+
+   "${testMode}" || "${@}" || {
+      local status="${?}"
+      logWarning "host command failed with exit status ${status}: ${*}"
+      return "${status}"
+   }
+}
+
+verifyActionFlags() {
+   local allFlag="${1}"
+   shift 1
+
+   local allRequested
+   getVariable "${allFlag}" allRequested
+   local actionFlag
+
+   for actionFlag in "${@}"
+   do
+      local actionRequested
+      getVariable "${actionFlag}" actionRequested
+
+      "${actionRequested}" && {
+         "${allRequested}" && syntaxError "conflicting actions"
+         return
+      }
+   done
+
+   "${allRequested}" || syntaxError "no actions"
+
+   for actionFlag in "${@}"
+   do
+      setVariable "${actionFlag}" true
+   done
+}
+
+testInteger() {
+   local value="${1}"
+
+   [ "${value}" = "0" ] || {
+      value="${value#-}"
+      [ -n "${value}" ] || return 1
+      [ "$(expr "${value}" : '^[1-9][0-9]*$')" -eq "${#value}" ] || return 1
+   }
+
+   return 0
+}
+
+verifyInteger() {
+   local label="${1}"
+   local value="${2}"
+   local minimum="${3}"
+   local maximum="${4}"
+
+   testInteger "${value}" || {
+      semanticError "${label} not an integer: ${value}"
+   }
+
+   [ -n "${minimum}" ] && {
+      [ "${value}" -lt "${minimum}" ] && {
+         semanticError "${label} out of range: ${value} < ${minimum}"
+      }
+   }
+
+   [ -n "${maximum}" ] && {
+      [ "${value}" -gt "${maximum}" ] && {
+         semanticError "${label} out of range: ${value} > ${maximum}"
+      }
+   }
+}
+
 testContainingDirectory() {
    local directory="${1}"
    shift 1
@@ -274,14 +427,6 @@ findContainingDirectory() {
    export "${variable}"="${directory}"
 }
 
-verifyExecutable() {
-   local path="${1}"
-
-   [ -e "${path}" ] || semanticError "file not found: ${path}"
-   [ -f "${path}" ] || semanticError "not a file: ${path}"
-   [ -x "${path}" ] || semanticError "file not executable: ${path}"
-}
-
 testDirectory() {
    local path="${1}"
 
@@ -290,6 +435,46 @@ testDirectory() {
    return 0
 }
 
+verifyWritableDirectory() {
+   local path="${1}"
+
+   testDirectory "${path}" || semanticError "directory not found: ${path}"
+   [ -w "${path}" ] || semanticError "directory not writable: ${path}"
+}
+
+testFile() {
+   local path="${1}"
+
+   [ -e "${path}" ] || return 1
+   [ -f "${path}" ] || semanticError "not a file: ${path}"
+   return 0
+}
+
+verifyInputFile() {
+   local path="${1}"
+
+   testFile "${path}" || semanticError "file not found: ${path}"
+   [ -r "${path}" ] || semanticError "file not readable: ${path}"
+}
+
+verifyOutputFile() {
+   local path="${1}"
+
+   if testFile "${path}"
+   then
+      [ -w "${path}" ] || semanticError "file not writable: ${path}"
+   else
+      verifyWritableDirectory "$(dirname "${path}")"
+   fi
+}
+
+verifyExecutableFile() {
+   local path="${1}"
+
+   testFile "${path}" || semanticError "file not found: ${path}"
+   [ -x "${path}" ] || semanticError "file not executable: ${path}"
+}
+
 verifyInputDirectory() {
    local path="${1}"
 
@@ -308,19 +493,6 @@ verifyOutputDirectory() {
    fi
 }
 
-needTemporaryDirectory() {
-   cleanup() {
-      set +e
-      cd /
-      [ -z "${temporaryDirectory}" ] || rm -f -r -- "${temporaryDirectory}"
-   }
-   trap "cleanup" 0
-
-   umask 022
-   [ -n "${TMPDIR}" -a -d "${TMPDIR}" -a -r "${TMPDIR}" -a -w "${TMPDIR}" -a -x "${TMPDIR}" ] || export TMPDIR="/tmp"
-   temporaryDirectory="$(mktemp -d "${TMPDIR}/${programName}.XXXXXX")" && cd "${temporaryDirectory}" || exit "${?}"
-}
-
 programParameterCount=0
 programParameterCountMinimum=-1
 programParameterLabelWidth=0
@@ -347,8 +519,10 @@ optionalProgramParameters() {
    if [ "${programParameterCountMinimum}" -lt 0 ]
    then
       programParameterCountMinimum="${programParameterCount}"
+      optionalProgramParameterLabel="${1}"
+      optionalProgramParameterUsage="${2}"
    else
-      logMessage warning "program parameters are already optional"
+      logWarning "program parameters are already optional"
    fi
 }
 
@@ -408,6 +582,10 @@ addProgramOption() {
    [ "${length}" -eq 0 ] || programOptionString="${programOptionString}:"
 }
 
+addTestModeOption() {
+   addProgramOption t flag testMode "test mode - log (but don't execute) the host commands"
+}
+
 addProgramUsageLine() {
    local line="${1}"
 
@@ -470,10 +648,19 @@ showProgramUsageSummary() {
       index=$((index + 1))
    done
 
+   [ -z "${optionalProgramParameterLabel}" ] || {
+      line="${line} [${optionalProgramParameterLabel} ...]"
+
+      [ -z "${optionalProgramParameterUsage}" ] || {
+         addProgramParameter "${optionalProgramParameterLabel} ..." optionalProgramParameterVariable "${optionalProgramParameterUsage}"
+      }
+   }
+
    line="${line}${suffix}"
    addProgramUsageLine "${line}"
 
    [ "${programParameterCount}" -eq 0 ] || {
+      addProgramUsageLine ""
       addProgramUsageLine "Parameters:"
 
       local indent=$((programParameterLabelWidth + 2))
@@ -490,7 +677,7 @@ showProgramUsageSummary() {
 
          local usage="$(getVariable "programParameterUsage_${index}")"
          local default="$(getVariable "programParameterDefault_${index}")"
-         [ -z "${default}" ] || usage="${usage} (default is ${default})"
+         [ -z "${default}" ] || usage="${usage} - the default is ${default}"
          addProgramUsageText "${usage}" "${width}" "  ${line}"
 
          index=$((index + 1))
@@ -498,6 +685,7 @@ showProgramUsageSummary() {
    }
 
    [ "${#}" -eq 0 ] || {
+      addProgramUsageLine ""
       addProgramUsageLine "Options:"
 
       local indent=$((3 + programOptionOperandWidth + 2))
@@ -514,7 +702,7 @@ showProgramUsageSummary() {
 
          usage="$(getVariable "programOptionUsage_${letter}")"
          local default="$(getVariable "programOptionDefault_${letter}")"
-         [ -z "${default}" ] || usage="${usage} (default is ${default})"
+         [ -z "${default}" ] || usage="${usage} - the default is ${default}"
          addProgramUsageText "${usage}" "${width}" "  ${line}"
       done
    }
@@ -529,7 +717,7 @@ showProgramUsageSummary() {
    showProgramUsageNotes
 }
 
-addProgramOption h flag programOption_showUsageSummary "show usage summary (this output), and then exit"
+addProgramOption h flag programOption_showUsageSummary "show (this) usage summary, and then exit"
 addProgramOption q counter programOption_quietCount "decrease output verbosity"
 addProgramOption v counter programOption_verboseCount "increase output verbosity"
 
